import { SpreadsheetVisualDataBase } from "./SpreadsheetVisualDataBase";
import { IEnumerable, Type } from "igniteui-webcomponents-core/ES2015/type";
import { RectData } from "igniteui-webcomponents-core/ES2015/RectData";
import { PrimitiveVisualDataList } from "igniteui-webcomponents-core/ES2015/PrimitiveVisualDataList";
import { List$1 } from "igniteui-webcomponents-core/ES2015/List$1";
/**
 * Represents the visual data for the spreadsheet.
 */
export declare class SpreadsheetVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _cellAreas;
    /**
     * Returns or sets the visual data for the cell areas in the spreadsheet
     */
    get cellAreas(): SpreadsheetCellAreaVisualDataList;
    set cellAreas(a: SpreadsheetCellAreaVisualDataList);
    private _rowHeaderAreas;
    /**
     * Returns or sets the visual data for the row header areas in the spreadsheet
     */
    get rowHeaderAreas(): SpreadsheetHeaderAreaVisualDataList;
    set rowHeaderAreas(a: SpreadsheetHeaderAreaVisualDataList);
    private _columnHeaderAreas;
    /**
     * Returns or sets the visual data for the column header areas in the spreadsheet
     */
    get columnHeaderAreas(): SpreadsheetHeaderAreaVisualDataList;
    set columnHeaderAreas(a: SpreadsheetHeaderAreaVisualDataList);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
    /**
     * @hidden
     */
    static _f(a: any): string;
    /**
     * @hidden
     */
    static _e(a: IEnumerable): string;
    /**
     * @hidden
     */
    static _g(a: string[], b: any[]): string;
}
/**
 * Represents the visual data for a row or column header area within the spreadsheet
 */
export declare class SpreadsheetHeaderAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    get relativeBounds(): RectData;
    set relativeBounds(a: RectData);
    private _items;
    /**
     * The visual information about the items in the header
     */
    get items(): SpreadsheetRowColumnVisualDataList;
    set items(a: SpreadsheetRowColumnVisualDataList);
    private _shapes;
    /**
     * The visual shape data of the header area.
     */
    get shapes(): PrimitiveVisualDataList;
    set shapes(a: PrimitiveVisualDataList);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of row or column header areas within the spreadsheet
 */
export declare class SpreadsheetHeaderAreaVisualDataList extends List$1<SpreadsheetHeaderAreaVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for a cell area within the spreadsheet
 */
export declare class SpreadsheetCellAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    get relativeBounds(): RectData;
    set relativeBounds(a: RectData);
    private _columns;
    /**
     * The visual information about the columns for the cells
     */
    get columns(): SpreadsheetRowColumnVisualDataList;
    set columns(a: SpreadsheetRowColumnVisualDataList);
    private _rows;
    /**
     * The visual information about the rows for the cells
     */
    get rows(): SpreadsheetRowColumnVisualDataList;
    set rows(a: SpreadsheetRowColumnVisualDataList);
    private _shapes;
    /**
     * The visual shape data of the header area.
     */
    get shapes(): PrimitiveVisualDataList;
    set shapes(a: PrimitiveVisualDataList);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of cell areas within the spreadsheet
 */
export declare class SpreadsheetCellAreaVisualDataList extends List$1<SpreadsheetCellAreaVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for a row or column within the spreadsheet
 */
export declare class SpreadsheetRowColumnVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    private _index;
    /**
     * The index of the associated row or column.
     */
    get index(): number;
    set index(a: number);
    private _offset;
    /**
     * The start offset of the row or column within the containing visual.
     */
    get offset(): number;
    set offset(a: number);
    private _extent;
    /**
     * The extent of the row or column within the containing visual.
     */
    get extent(): number;
    set extent(a: number);
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of row or column headers within the spreadsheet
 */
export declare class SpreadsheetRowColumnVisualDataList extends List$1<SpreadsheetRowColumnVisualData> {
    static $t: Type;
    constructor();
}
